@@ -4,6 +4,13 @@ my_instance_crn='crn%3Av1%3Abluemix%3Apublic%3Asql-query%3Aus-south%3Aa%2Fd86af7
 my_target_cos_url='cos://us-south/sqltempregional/'
 sqlClient = ibmcloudsql.SQLQuery(my_bluemix_apikey, my_instance_crn, my_target_cos_url, client_info='ibmcloudsql test')
 
+
+print("Running test with SQL grammar error:")
+sqlClient.run_sql("SELECT xyzFROM cos://us-geo/sql/employees.parquet STORED AS PARQUET LIMIT 10")
+
+print("Running test with SQL runtime error:")
+sqlClient.run_sql("SELECT xyz FROM cos://us-geo/sql/employees.parquet STORED AS PARQUET LIMIT 10")
+
 print("Running test with individual method invocation:")
 sqlClient.logon()
 jobId = sqlClient.submit_sql("SELECT * FROM cos://us-geo/sql/employees.parquet STORED AS PARQUET LIMIT 10")
